@@ -22,7 +22,7 @@ from textwrap import dedent
 
 from hspylib.core.enums.charset import Charset
 from hspylib.core.tools.commons import syserr
-from hspylib.core.tools.zoned_datetime import now
+from hspylib.core.zoned_datetime import now
 from hspylib.modules.cli.application.application import Application
 from hspylib.modules.cli.application.version import Version
 
